/* undirected incidence-list graph implementation */

#include <fstream>
#include <iostream>
#include <string>

#include "dijkstra.h"
#include "undir-inclist-graph.h"

int main(int argc, char** argv)
{
   /*
    * read graph data from file argv[1]
    */
   if(argc < 2)
   {
      std::cerr << "Error! Input file name required as command line argument, but missing.\n";
      return EXIT_FAILURE;
   }
   std::clog << "\tlog output: Reading from " << argv[1] << ".\n";
   
   std::ifstream infile(argv[1]);
   if(!infile)
   {
      std::cerr << "Error! File " << argv[1] << " cannot be read.\n";
      return EXIT_FAILURE;
   }
   
   graph::UndirInclistGraph g;
   infile >> g;
   infile.close();
   
   std::cout << "\n*** ERASING Oslo NODE ***\n";
   g.erase_node("Oslo");
   std::cout << "\n*** ERASING Ås-Moss EDGE ***\n";
   g.erase_edge("Ås", "Moss");
   
   std::cout << "\nContent of graph g:\n" << g << "\n";
   
   std::cout << "\n*** SHORTEST PATH COMPUTATION (Ås as root node) ***\n";
   std::cout.flush();
   std::string root_label = "Ås";
   graph::UndirInclistGraph h = std::move(graph::shortest_paths(&g, root_label));  // construct tree of shortest paths
   std::cout << "\nThe following spanning tree h was computed, containing the shortest paths from "
             << root_label << ":\n" << h << "\n";
}
